"""
Tests Client.
"""

import unittest
from yototec.client import Client


class TestClient(unittest.TestCase):
    """
    Tests Client
    """

    @classmethod
    def setUpClass(cls) -> None:
        """
        Create a single Client instance for all tests.
        """
        # Replace "YOUR_API_KEY" with a valid API key for testnet or use environment variables
        cls.api_key = "YOUR_API_KEY"  # type: ignore
        cls.client_user = Client(api_key=cls.api_key)  # type: ignore

    def test_01_get_data(self) -> None:
        """
        Get a time series of aggregated price data.
        """
        data = self.client_user.get_data(tic="ETHUSD", sdate="2025-01-01T00:00:00", edate="2025-01-01T01:00:00", freq="minute")  # type: ignore
        self.assertIsNone(
            data, "You may replace YOUR_API_KEY with a valid API key for tests."
        )

    def test_02_get_data_last(self) -> None:
        """
        Get the latest available aggregated price data.
        """
        data = self.client_user.get_data_last(tic="ETHUSD", freq="minute")  # type: ignore
        self.assertIsNone(
            data, "You may replace YOUR_API_KEY with a valid API key for tests."
        )


if __name__ == "__main__":
    unittest.main()



"""
A Python Client to interact with the Yototec Market API.
"""

from typing import Dict, Optional
import requests  # type: ignore


BASE_URL = "https://market.yototec.com"


class Client:
    """
    A Python client that wraps interactions with the Yototec Market API.
    """

    def __init__(self, base_url: str = BASE_URL, api_key: str = ""):
        """
        Initialize the client with a base URL and an optional API key.
        """
        self.base_url = base_url.rstrip("/")
        self.api_key = api_key

    def get_data(
        self, tic: str, sdate: str, edate: str, freq: str = "minute"
    ) -> Optional[Dict[str, Dict[str, float]]]:
        """
        Return a time series of aggregated prices for a ticker in a user-defined
        `freq` (i.e. "minute", "hour", "day") in range [`sdate`, `edate`],
        where `sdate` and `edate` should follow ISO 8601
        https://www.iso.org/iso-8601-date-and-time-format.html
        A valid query-param `api_key` is required.
        """
        resp = requests.get(
            f"{self.base_url}/data/get_data?tic={tic}&sdate={sdate}&edate={edate}&freq={freq}&api_key={self.api_key}",
        )
        if resp.status_code == 200:
            data: Dict[str, Dict[str, float]] = resp.json()
            return data
        return None

    def get_data_last(
        self, tic: str, freq: str = "minute"
    ) -> Optional[Dict[str, Dict[str, float]]]:
        """
        Return the latest available aggregated price for a ticker in a user-defined
        `freq` (i.e. "minute", "hour", "day").
        A valid query-param `api_key` is required.
        """
        resp = requests.get(
            f"{self.base_url}/data/get_data_last?tic={tic}&freq={freq}&api_key={self.api_key}",
        )
        if resp.status_code == 200:
            data: Dict[str, Dict[str, float]] = resp.json()
            return data
        return None
